@@ -1,11 +1,6 @@
 #!/usr/local/bin/perl
 
 ###	perl -I t -I lib -MPOEIKCdaemon -e POEIKCdaemon::daemon
-$ARGV[0] or exit(print "
-### perl eg/client_lite.pl 1 
-### perl eg/client_lite.pl 2 
-### perl eg/client_lite.pl :
-\n");
 
 use strict;
 use warnings;
@@ -18,7 +13,7 @@ use Sys::Hostname;
 	my $port = $ARGV[1] || 54321;
 
 	print scalar localtime,"\n";
-	printf "[ %s : %s ]\n", $host, $port;
+	printf "[poeikcd ..  %s / PORT:%s]\n", $host, $port;
 
 	my ($name) = $0 =~ /(\w+)\.\w+/;
 	$name .= $$;
@@ -42,24 +37,34 @@ use Sys::Hostname;
 		['POEIKCdaemon::Utility' => 'reload', 'POEIKCdaemon::Utility'],
 		['POEIKCdaemon::Utility' => 'get_H_ENV'],
 		['POEIKCdaemon::Utility' => 'get_A_INC'],
+		['POEIKCdaemon::Utility' => 'unshift_INC', './t'],
+		['POEIKCdaemon::Utility' => 'unshift_INC', '~/lib'],
+		['POEIKCdaemon::Utility' => 'delete_INC', './t'],
+		['POEIKCdaemon::Utility' => 'reset_INC'],
 		['POEIKCdaemon::Utility' => 'get_H_INC'],
 		['POEIKCdaemon::Utility' => 'get_pid'],
-		['POEIKCdaemon::Utility' => 'get_port'],
+		['POEIKCdaemon::Utility' => 'get_object_something', 'ikc_self_port'],
+		['POEIKCdaemon::Utility' => 'get_object_something', 'session_alias'],
 		['POEIKCdaemon::Utility' => 'get_stay'],
+		['POEIKCdaemon::Utility' => 'get_VERSION'],
 		['POEIKCdaemon::Utility' => 'stop'],
 		['Cwd' => 'getcwd'],
 		['IKC_d_Localtime' => 'timelocal'],
 		['POEIKCdaemon::Utility' => 'reload', 'IKC_d_Localtime'],
 		['POEIKCdaemon::Utility' => 'reload', 'IKC_d_Localtime' => 'timelocal'],
 		['POEIKCdaemon::Utility' => 'stay', 'IKC_d_Localtime' ],
-		[],
-		[],
+		['POEIKCdaemon::Utility' => 'get_Class_Inspector', 'POEIKCdaemon::Utility'],
+		['POEIKCdaemon::Utility' => 'get_Class_Inspector', 'POEIKCdaemon::Utility','methods'],
 		['Cwd' => 'getcwd'],
 		['LWP::Simple' => 'get', 'http://search.cpan.org/~suzuki/'],
 	);
 
 
-	printf "%s => %s\n", $_, Dumper $exe{$_} for sort {$a<=>$b} keys %exe;
+	printf "%2d => %s\n", $_, join("\t"=> @{$exe{$_}}) for sort {$a<=>$b} keys %exe;
+
+	print '*' x 20, "\n";
+
+	$ARGV[0] or printf(" perl eg/client_lite.pl [1 .. %d]", scalar(keys %exe)-1), exit;
 
 	printf "[%d]\t%s\n", $ARGV[0], join "\t"=>@{$exe{ $ARGV[0] }};
 
